@@ -4,7 +4,7 @@ use warnings;
 package Number::Tolerant;
 use base qw(Exporter);
 
-our $VERSION = "1.601";
+our $VERSION = "1.700";
 
 use Sub::Exporter::Util;
 use Sub::Exporter -setup => {
@@ -13,6 +13,7 @@ use Sub::Exporter -setup => {
 };
 
 use Carp ();
+use Scalar::Util ();
 
 =head1 NAME
 
@@ -20,7 +21,7 @@ Number::Tolerant - tolerance ranges for inexact numbers
 
 =head1 VERSION
 
-version 1.601
+version 1.700
 
 =head1 SYNOPSIS
 
@@ -158,7 +159,7 @@ sub new {
     next unless my @args = $type->valid_args(@_);
     my $guts = $type->construct(@args);
 
-    return $guts unless ref $guts;
+    return $guts unless ref $guts and not Scalar::Util::blessed($guts);
 
     if (
       defined $guts->{min} and defined $guts->{max} and
@@ -206,15 +207,21 @@ sub from_string {
 
 sub stringify {
   my ($self) = @_;
-  return 'any number' unless $self->{min} || $self->{max};
+
+  return 'any number' unless (defined $self->{min} || defined $self->{max});
+
   my $string = '';
-  if ($self->{min}) {
+
+  if (defined $self->{min}) {
     $string .= "$self->{min} <" . ($self->{exclude_min} ? q{} : '=') . q{ };
   }
+
   $string .= 'x';
-  if ($self->{max}) {
+
+  if (defined $self->{max}) {
     $string .= ' <' . ($self->{exclude_max} ? q{} : '=') .  " $self->{max}";
   }
+
   return $string;
 }
 
@@ -289,6 +296,7 @@ sub _intersection {
   } else {
     $min = $_[0]->{min} || $_[1]->{min};
   }
+
   $exclude_min = 1
     if ($_[0]{min} and $min == $_[0]{min} and $_[0]{exclude_min})
     or ($_[1]{min} and $min == $_[1]{min} and $_[1]{exclude_min});
@@ -298,15 +306,22 @@ sub _intersection {
   } else {
     $max = $_[0]->{max} || $_[1]->{max};
   }
+
   $exclude_max = 1
     if ($_[0]{max} and $max == $_[0]{max} and $_[0]{exclude_max})
     or ($_[1]{max} and $max == $_[1]{max} and $_[1]{exclude_max});
 
   return $_[0]->new('infinite') unless defined $min || defined $max;
+
   return $_[0]->new($min => ($exclude_min ? 'more_than' : 'or_more'))
     unless defined $max;
+
   return $_[0]->new($max => ($exclude_max ? 'less_than' : 'or_less'))
     unless defined $min;
+
+  Carp::confess "no valid intersection of ($_[0]) and ($_[1])"
+    if $max < $min or $min > $max;
+
   bless {
     max => $max,
     min => $min,
