@@ -4,7 +4,7 @@ use warnings;
 package Number::Tolerant::Type::less_than;
 use base qw(Number::Tolerant::Type);
 
-our $VERSION = '1.601';
+our $VERSION = '1.700';
 
 sub construct { shift; { value => $_[0], max => $_[0], exclude_max => 1 } }
 
@@ -24,11 +24,18 @@ sub parse {
 
 sub valid_args {
   my $self = shift;
-  my $number = $self->number_re;
-  if ((grep { defined } @_) == 2) {
-    return ($_[1]) if ($_[1] =~ $number) and ($_[0] eq 'less_than');
-    return ($_[0]) if ($_[0] =~ $number) and ($_[1] eq 'less_than');
+
+  return unless 2 == grep { defined } @_;
+
+  for my $i ( [0,1], [1,0] ) {
+    if (
+      $_[ $i->[0] ] eq 'less_than'
+      and defined (my $num = $self->normalize_number($_[ $i->[1] ]))
+    ) {
+      return $num;
+    }
   }
+
   return;
 }
 
