@@ -4,7 +4,7 @@ use warnings;
 package Number::Tolerant::Type::or_less;
 use base qw(Number::Tolerant::Type);
 
-our $VERSION = '1.601';
+our $VERSION = '1.700';
 
 sub construct { shift; { value => $_[0], max => $_[0] } }
 
@@ -24,12 +24,11 @@ sub parse {
 
 sub valid_args {
   my $self = shift;
-  my $number = $self->number_re;
 
-  return ($_[0])
-    if ((grep { defined } @_) == 2)
-    and ($_[0] =~ $number) and ($_[1] eq 'or_less');
-  return;
+  return unless 2 == grep { defined } @_;
+  return unless $_[1] eq 'or_less';
+
+  return $self->normalize_number($_[0]);
 }
 
 1;
