@@ -4,7 +4,7 @@ use warnings;
 package Number::Tolerant::Type::plus_or_minus;
 use base qw(Number::Tolerant::Type);
 
-our $VERSION = '1.601';
+our $VERSION = '1.700';
 
 sub construct { shift;
   {
@@ -29,14 +29,14 @@ sub stringify { "$_[0]->{value} +/- $_[0]->{variance}"  }
 
 sub valid_args {
   my $self = shift;
-  my $number = $self->number_re;
 
-  return ($_[0],$_[2])
-    if ((grep { defined } @_) == 3)
-    and ($_[0] =~ $number)
-    and ($_[1] eq 'plus_or_minus')
-    and ($_[2] =~ $number);
-  return;
+  return unless 3 == grep { defined } @_;
+  return unless $_[1] eq 'plus_or_minus';
+
+  return unless defined (my $base = $self->normalize_number($_[0]));
+  return unless defined (my $var  = $self->normalize_number($_[2]));
+
+  return ($base, $var);
 }
 
 1;
